ACTAB
===========
.. image:: https://github.com/MariamAhmedAbdElhaleem/ACLC_BA/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/MariamAhmedAbdElhaleem/ACLC_BA/actions/workflows/tests.yml
.. image:: https://img.shields.io/badge/License-GPLv3-blue.svg
   :target: https://opensource.org/licenses/GPL-3.0

ACTAB (Arabic Centre Tools by Bibliotheca Alexandrina) is a collection of open source Python modules for Arabic language processing developed by `Bibliotheca Alexandrina <http://bibalex.org>`_.




Installation
------------
You will need Python > ...

Linux/macOS
~~~~~~~~~~~

Install using pip
^^^^^^^^^^^^^^^^^
.. code-block:: bash

   pip install actab

   # or run the following if you already have actab installed
   pip install actab-tools --upgrade

Install from source
^^^^^^^^^^^^^^^^^^^

.. code-block:: bash

   # Clone the repo
   git clone https://github.com/ba-aclc/actab
   cd actab

   # Install from source
   pip install .

   # or run the following if you already have actab installed
   pip install --upgrade .

Windows
~~~~~~~

Install using pip
^^^^^^^^^^^^^^^^^

.. code-block:: bash

   pip install actab ......

   # or run the following if you already have actab installed
   pip install --upgrade ........ actab


Install from source
^^^^^^^^^^^^^^^^^^^

.. code-block:: bash

   # Clone the repo
   git clone https://github.com/ba-aclc/actab
   cd actab

   # Install from source
   pip install ...... .
   pip install --upgrade ....... .

Documentation
-------------

Citation
--------

If you find actab useful in your research, please cite
`our paper <https://scholar.google.com/>`_:

.. code-block:: bibtex

   @{,
      title = "",
      author = "",
      month = ,
      year = "",
      publisher = "",
      url = "",
      abstract = "We present actab, a collection of open-source tools for Arabic natural language processing",
      language = "English",
      ISBN = "",
   }

License
-------

ACTAB is available under the GNU General Public License v3.0.
See the `LICENSE file
<https://github.com/ba-aclc/actab/.../main/LICENSE>`_
for more info.


Contribute
----------

If you would like to contribute to ACTAB, please read the
`CONTRIBUTE.rst
<https://github.com/ba-aclc/actab/.../main/CONTRIBUTING.rst>`_
file.
